@@ -1,15 +1,13 @@
 package Text::MagicTemplateX;
-$VERSION = 1.01;
+$VERSION = 1.05;
 __END__
 
 =head1 NAME
 
-Text::MagicTemplateX - namespace used by the extension of Text::MagicTemplate
+Text::MagicTemplateX - namespace used by the extensions of Text::MagicTemplate
 
 =head1 DESCRIPTION
 
-You need to read this documentation only if you are about to write your own extension, or if you are curious.
-
 Text::MagicTemplateX:: is the namespace used by the extensions of Text::MagicTemplate. This documentation cover the extension system in general: each extension collection is supposed to be documented with its own POD file.
 
 Extensions are simple files that Text::MagicTemplate will include with the do() statement when it construct a new object. See L<Text::MagicTemplate/-markers> and L<Text::MagicTemplate/-behaviours> for details.
@@ -220,6 +218,8 @@ L<Text::MagicTemplate|Text::MagicTemplate>, L<Text::MagicTemplate::Tutorial|Text
 
 =head1 SUPPORT and FEEDBACK
 
+More information at http://perl.4pro.net/?Text::MagicTemplateX.
+
 I would like to have just a line of feedback from everybody who tries or actually uses this software. Feel free to write me any comment, suggestion or request.
 
 =head1 AUTHOR
