@@ -1,5 +1,5 @@
 package Text::MagicTemplateX::Core;
-$VERSION = 1.01;
+$VERSION = 1.05;
 __END__
 
 =head1 NAME
@@ -37,6 +37,10 @@ L<Text::MagicTemplate> (general documentation about the I<MagicTemplate> system)
 
 L<Text::MagicTemplate::Tutorial|Text::MagicTemplate::Tutorial>
 
+=item *
+
+L<Text::MagicTemplateXl|Text::MagicTemplateX>
+
 =back
 
 =head1 CORE MARKERS
@@ -266,6 +270,8 @@ L<Text::MagicTemplate|Text::MagicTemplate>, L<Text::MagicTemplate::Tutorial|Text
 
 =head1 SUPPORT and FEEDBACK
 
+More information at http://perl.4pro.net/?Text::MagicTemplateX::Core.
+
 I would like to have just a line of feedback from everybody who tries or actually uses this software. Feel free to write me any comment, suggestion or request.
 
 =head1 AUTHOR
